namespace DysonNetwork.Common.Models.Auth;

/// <summary>
/// Represents the different types of authentication factors that can be used for multi-factor authentication.
/// </summary>
public enum AuthFactorType
{
    /// <summary>
    /// Password-based authentication factor.
    /// </summary>
    Password = 0,
    
    /// <summary>
    /// Time-based One-Time Password (TOTP) authentication factor.
    /// </summary>
    Totp = 1,
    
    /// <summary>
    /// Email-based authentication factor.
    /// </summary>
    Email = 2,
    
    /// <summary>
    /// Phone/SMS-based authentication factor.
    /// </summary>
    Phone = 3,
    
    /// <summary>
    /// Security key (FIDO2/WebAuthn) authentication factor.
    /// </summary>
    SecurityKey = 4,
    
    /// <summary>
    /// Recovery code authentication factor.
    /// </summary>
    RecoveryCode = 5,
    
    /// <summary>
    /// Backup code authentication factor.
    /// </summary>
    BackupCode = 6,
    
    /// <summary>
    /// OpenID Connect (OIDC) authentication factor.
    /// </summary>
    Oidc = 7
}
